==> haskell-echo-0.1.4-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 echo
version:              0.1.4
visibility:           public
id:                   echo-0.1.4-9WkOqrcNnDn8K5KbomRoSw
key:                  echo-0.1.4-9WkOqrcNnDn8K5KbomRoSw
license:              BSD-3-Clause
copyright:            (C) 2016-2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/echo
synopsis:
    A cross-platform, cross-console way to handle echoing terminal input

description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!

    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.

category:             System
abi:                  b3915c2316e8ca0497732dec713843ce
exposed:              True
exposed-modules:      System.IO.Echo System.IO.Echo.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/echo-0.1.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/echo-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/echo-0.1.4
hs-libraries:         HSecho-0.1.4-9WkOqrcNnDn8K5KbomRoSw
depends:              base-4.15.0.0 process-1.6.11.0
haddock-interfaces:   /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html:         /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-echo-0.1.4-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 echo
version:              0.1.4
visibility:           public
id:                   echo-0.1.4-AolexdhZ6jY9N2bVe52aSD
key:                  echo-0.1.4-AolexdhZ6jY9N2bVe52aSD
license:              BSD-3-Clause
copyright:            (C) 2016-2017 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
stability:            Provisional
homepage:             https://github.com/RyanGlScott/echo
synopsis:
    A cross-platform, cross-console way to handle echoing terminal input

description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!

    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.

category:             System
abi:                  20b850af636a991f97041dbc574fb3c3
exposed:              True
exposed-modules:      System.IO.Echo System.IO.Echo.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/echo-0.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/echo-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/echo-0.1.4
hs-libraries:         HSecho-0.1.4-AolexdhZ6jY9N2bVe52aSD
depends:              base-4.15.1.0 process-1.6.13.2
haddock-interfaces:   /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html:         /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
